# System: Charging a Capacitor in an RC Circuit
# Program to generate a plot of charge vs. time
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial conditions for charging a capacitor
Q0 = 0.0
V0 = 1.5
R = 1.0e03
C = 1.0e-06

# Define plot parameters
plot_file = "charging_capacitor.png"
plot_dpi = 900
title_in = "RC Circuit (Charging): "
title_in += "dq/dt = (V$_0$C- q)/RC\n"
title_in += "q$_0$ = 0 C, R = 1k$\Omega$, C = 1 $\mu$F, V$_0$ = 1.5 V"
x_label_in = "t(s)"
y_label_in = "q(C)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 0.0,10*R*C,1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
function2plot = V0*C*(1 - np.exp(-x/(R*C)))

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)