# System: Particle with a Constant Acceleration
# Program to generate a plot of position vs. time
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial conditions
x0 = 2.0
v0 = 5.0

# Set up constant
a = 1.0

# Define plot parameters
plot_file = "position.png"
plot_dpi = 900
title_in = "Particle with a Constant Acceleration: dx/dt = v$_0$ + at,\n"
title_in += "a = 1.0 m/s$^2$, v$_0$ = 5.0 m/s, x$_0$ = 2.0 m/s"
x_label_in = "t(s)"
y_label_in = "x(m)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 0.0,20.0,1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
function2plot = x0 + v0*x + (1/2)*a*x**2

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)