# System: Ballistic Movement
# Program to generate a plot of vertical position vs. time for balistic movement
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial conditions
y0 = 0.0
v0 = 30.0
theta0 = 45.0

# Set up constant
g = 9.8

# Define plot parameters
plot_file = "vertical_position.png"
plot_dpi = 900
title_in = "Ballistic Movement: dy/dt = v$_0$sin $\\theta_0$ - gt,\n"
title_in += "g = 9.8 m/s$^2$, v$_0$ = 30.0 m/s, y$_0$ = 0 m"
x_label_in = "t(s)"
y_label_in = "y(m)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 0.0,5.0,1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
function2plot = y0 + v0*np.sin(theta0)*x - (1/2)*g*x**2

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)