# System: Space Shuttle (STS-121)
# Program to generate a plot of velocity vs. time
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial conditions
v0 = 0.0
a0 = 8.302
a1 = -0.08874
a2 = 1.6836e-04

# Define plot parameters
plot_file = "velocity_STS-121.png"
plot_dpi = 900
title_in = "Space Shuttle (STS-121): dv/dt = a$_0$ + a$_1$t + a$_2$t$^2$,\n"
title_in += "v$_0$ = 0 m/s, a$_0$ = 8.392 m/s$^2$, a$_1$ = -0.08874 m/s$^3$, "
title_in += "a$_2$ = 1.6836.10$^{-4}$ m/s$^4$"
x_label_in = "t(s)"
y_label_in = "v(m/s)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 0.0,520.0,1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
function2plot = v0 + a0*x + (a1/2)*x**2 + (a2/3)*x**3

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)