# System: Terminal Velocity
# Program to generate a plot of velocity vs. time
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial conditions
v0 = 0.0

# Define constants
g = 9.8
b = 13.0
m = 65.0

# Define plot parameters
plot_file = "terminal_velocity.png"
plot_dpi = 900
title_in = "Terminal Velocity: dv/dt = g - (b/m)v,\n"
title_in += "v$_0$ = 0 m/s, g = 9.8 m/s$^2$, b = 13.0 kg.s$^{-1}$, "
title_in += "m = 65 kg"
x_label_in = "t(s)"
y_label_in = "v(m/s)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 0.0,100.0,1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
function2plot = (m*g/b)*(1-np.exp(-b*x/m))

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)