# System: Newton's Law of Cooling
# Program to generate a plot of velocity vs. time
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial conditions
T0 = 100.0

# Define constants
T1 = 20.0
k = 0.1

# Define plot parameters
plot_file = "temperature.png"
plot_dpi = 900
title_in = "Newton's Law of Cooling: dT/dt = $\lambda$(T$_0$-T),\n"
title_in += "T$_0$ = 100.0 $^\circ$C, T$_1$ = 20.0 $^\circ$C, k = 0.1 s$^{-1}$"
x_label_in = "t(s)"
y_label_in = "T($^\circ$C)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 0.0,100.0,1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
function2plot = T0 - (T0-T1)*np.exp(-k*x)

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)