# System: RL Circuit After Disconnecting the Battery
# Program to generate a plot of current vs. time
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial conditions
i0 = 0.1
R = 50.0
L = 1.0

# Define plot parameters
plot_file = "RL_circuit.png"
plot_dpi = 900
title_in = "RL Circuit (After Disconnecting the Battery): "
title_in += "di/dt = - (R/L)i,\n"
title_in += "i$_0$ = 0.1A, R = 50 $\Omega$, L = 1 H"
x_label_in = "t(s)"
y_label_in = "i(A)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 0.0,10*(L/R),1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
function2plot = i0*np.exp(-R*x/L)

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)