# System: Mass-sprint
# Program to generate a plot of position vs. time
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial conditions
k = 1.0
m = 1.0
x0 = 0.1

# Define plot parameters
plot_file = "mass-spring_system.png"
plot_dpi = 900
title_in = "Mass-Spring System: "
title_in += "dv/dt = - (k/m)x,\n"
title_in += "x$_0$ = 0.1 m, k = 1.0 N/m, m = 1 kg"
x_label_in = "t(s)"
y_label_in = "x(m)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 0.0,10*np.pi,1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
omega = np.sqrt(k/m)
function2plot = x0*np.cos(omega*x)

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in,labelpad=-5)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)