# System: Ideal Rocket
# Program to generate a plot of velocity vs. mass
#
################################################################################
# Dr. Walter F. de Azevedo, Jr.                                                #
# https://azevedolab.net/                                                      #
# January 12, 2024                                                             #
################################################################################
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Initial condition
v_i = 0

# Define constants
v_rel = 5e3
M_i = 1e6
M_f = 1e5

# Define plot parameters
plot_file = "ideal_rocket.png"
plot_dpi = 900
title_in = "Rocket Equation: "
title_in += "-dM/M = (dv/v$_{rel}$)\n"
title_in += "v$_i$ = 0 m/s, v$_{rel}$ = 5.10$^3$ m/s,  M$_i$ = 1.10$^6$ kg"
x_label_in = "M$_i$/M"
y_label_in = "v(m/s)"
fontsize_title_in = 12
fontsize_x_label_in = 12
fontsize_y_label_in = 12
color_in = "blue"

# Define x-axis
start_x,end_x,n_points = 1.0,M_i/M_f,1000
x = np.linspace(start_x,end_x,n_points)

# Define function2plot
function2plot = v_i + v_rel*np.log(x)

# Plotting
plt.plot(x, function2plot, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig(plot_file,dpi=plot_dpi)